@@ -98,6 +98,7 @@ def main() -> int:
     properties_blocked: List[str] = ["modifierExtension"]
     complex_types: List[str] = []
     resource_types: List[str] = []
+    resource_types_fhir_name: List[str] = []
 
     # first pass, decide which items are resources or simple_types or complex_types
     # have to do two passes since an item at the beginning of the file may refer to an item at the end
@@ -270,6 +271,7 @@ def main() -> int:
                     file2.write(result)
             else:
                 file_path = complex_types_folder.joinpath(f"{resource_name.lower()}.py")
+                resource_types_fhir_name.append(resource_name)
                 print(
                     f"Writing complex_type: {resource_name.lower()} to {file_path}..."
                 )
@@ -277,6 +279,19 @@ def main() -> int:
                     file2.write(result)
 
             # print(result)
+    with open(data_dir.joinpath("template_index.jinja2"), "r") as file:
+        template_contents_index: str = file.read()
+        from jinja2 import Template
+
+        template_index = Template(
+            template_contents_index, trim_blocks=True, lstrip_blocks=True
+        )
+        result_index: str = template_index.render(resources=resource_types_fhir_name)
+        with open(
+            complex_types_folder.joinpath("resource_schema_index.py"), "w"
+        ) as file2:
+            file2.write(result_index)
+
     return 0
 
 
